require_relative '../../spec_helper'
# For Ruby < 1.9.3, use this instead of require_relative
# require (File.expand_path('./../../../spec_helper', __FILE__))

describe Datafiniti::User do

  describe "default attributes" do

    it "must include httparty methods" do
      Datafiniti::User.must_include HTTParty
    end

    it "must have the base url set to the Datafiniti API endpoint" do
      Datafiniti::User.base_uri.must_equal "https://#{ENV['DATAFINITI_API_KEY']}:@api.datafiniti.co"
    end

  end

  describe "default instance attributes" do

    let(:user) { Datafiniti::User.new(ENV['DATAFINITI_API_KEY']) }

    it "must have an id attribute" do
      user.must_respond_to :token
    end

    it "must have the right id" do
      user.token.must_equal ENV['DATAFINITI_API_KEY']
    end

  end


  describe "GET profile" do

    let(:user) { Datafiniti::User.new(ENV['DATAFINITI_API_KEY']) }

    before do
      VCR.insert_cassette 'user', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    # it "records the fixture" do
    #   # auth = {username: ENV['DATAFINITI_API_KEY'], password: ''}
    #   Datafiniti::User.get("/v2/users/#{ENV['DATAFINITI_API_KEY']}")
    # end

    it "must have a profile method" do
      user.must_respond_to :profile
    end

    it "must parse the api response from JSON to Hash" do
      user.profile.must_be_instance_of Hash
    end


    describe "dynamic attributes" do

      before do
        user.profile
      end

      it "must perform the request and get the data" do
        user.email.must_equal 'test@example.com'
      end
      it "must return the attribute value if present in profile" do
        user.active.must_equal "true"
        user.plan.must_equal JSON.parse('[{"plans": "100000M"}]')
      end

      it "must raise method missing if attribute is not present" do
        lambda { user.foo_attribute }.must_raise NoMethodError
      end

    end

    describe "caching" do

      # we use Webmock to disable the network connection after
      # fetching the profile
      before do
        user.profile
        stub_request(:any, /api.datafiniti.co/).to_timeout
      end

      it "must cache the profile" do
        user.profile.must_be_instance_of Hash
      end

      it "must refresh the profile if forced" do
        lambda { user.profile(true) }.must_raise Timeout::Error
      end

    end

  end
end
